<?php

namespace Drupal\remote_media_transcription\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Remote Media Transcription settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new SettingsForm.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'remote_media_transcription_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['remote_media_transcription.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('remote_media_transcription.settings');

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General Settings'),
      '#open' => TRUE,
    ];

    $form['general']['allowed_bundles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Allowed media bundles'),
      '#options' => $this->getMediaBundles(),
      '#default_value' => $config->get('allowed_bundles') ?: ['remote_video'],
      '#description' => $this->t('Select which media bundles can have transcriptions.'),
      '#required' => TRUE,
    ];

    $form['display'] = [
      '#type' => 'details',
      '#title' => $this->t('Display Settings'),
      '#open' => TRUE,
    ];

    $form['display']['show_button_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Show button text'),
      '#default_value' => $config->get('show_button_text') ?: $this->t('Show Transcription'),
      '#required' => TRUE,
    ];

    $form['display']['hide_button_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Hide button text'),
      '#default_value' => $config->get('hide_button_text') ?: $this->t('Hide Transcription'),
      '#required' => TRUE,
    ];

    $form['display']['animation_speed'] = [
      '#type' => 'number',
      '#title' => $this->t('Animation speed (ms)'),
      '#default_value' => $config->get('animation_speed') ?: 400,
      '#min' => 0,
      '#max' => 2000,
      '#step' => 100,
      '#description' => $this->t('Speed of the show/hide animation in milliseconds.'),
    ];

    $form['display']['default_state'] = [
      '#type' => 'select',
      '#title' => $this->t('Default state'),
      '#options' => [
        'hidden' => $this->t('Hidden'),
        'shown' => $this->t('Shown'),
      ],
      '#default_value' => $config->get('default_state') ?: 'hidden',
      '#description' => $this->t('Default state of the transcription when page loads.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('remote_media_transcription.settings')
      ->set('allowed_bundles', array_filter($form_state->getValue('allowed_bundles')))
      ->set('show_button_text', $form_state->getValue('show_button_text'))
      ->set('hide_button_text', $form_state->getValue('hide_button_text'))
      ->set('animation_speed', $form_state->getValue('animation_speed'))
      ->set('default_state', $form_state->getValue('default_state'))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Gets available media bundles.
   *
   * @return array
   *   Array of media bundle labels keyed by machine name.
   */
  protected function getMediaBundles() {
    $bundles = [];
    try {
      $bundle_info = $this->entityTypeManager->getStorage('media_type')->loadMultiple();
      foreach ($bundle_info as $key => $bundle) {
        $bundles[$key] = $bundle->label();
      }
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Error loading media bundles.'));
    }
    return $bundles;
  }

} 